Cassowary Roadmap
=================

Cassowary is a port to Python of existing implementations of the Cassowary
algorithm. To that extent, it is "feature complete".

However, the test suite for the original implementation is not especially
comprehensive. Contributions of additional tests (and any bug fixes revealed
by those tests) are most welcome.

Documentation improvements are also most welcome.
